==> mesa_12.0.4.orig.tar.gz: mesa-12.0.4/src/mesa/drivers/dri/i965/brw_meta_util.h <==
/*
 * Copyright © 2014 Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

#ifndef BRW_META_UTIL_H
#define BRW_META_UTIL_H

#include <stdbool.h>
#include "main/mtypes.h"
#include "intel_mipmap_tree.h"

#ifdef __cplusplus
extern "C" {
#endif

bool
brw_meta_mirror_clip_and_scissor(const struct gl_context *ctx,
                                 const struct gl_framebuffer *read_fb,
                                 const struct gl_framebuffer *draw_fb,
                                 GLfloat *srcX0, GLfloat *srcY0,
                                 GLfloat *srcX1, GLfloat *srcY1,
                                 GLfloat *dstX0, GLfloat *dstY0,
                                 GLfloat *dstX1, GLfloat *dstY1,
                                 bool *mirror_x, bool *mirror_y);

void
brw_get_fast_clear_rect(const struct brw_context *brw,
                        const struct gl_framebuffer *fb,
                        const struct intel_mipmap_tree* mt,
                        unsigned *x0, unsigned *y0,
                        unsigned *x1, unsigned *y1);

void
brw_get_resolve_rect(const struct brw_context *brw,
                     const struct intel_mipmap_tree *mt,
                     unsigned *x0, unsigned *y0,
                     unsigned *x1, unsigned *y1);

void
brw_meta_get_buffer_rect(const struct gl_framebuffer *fb, 
                         unsigned *x0, unsigned *y0,
                         unsigned *x1, unsigned *y1);

bool
brw_meta_set_fast_clear_color(struct brw_context *brw,
                              struct intel_mipmap_tree *mt,
                              const union gl_color_union *color);

bool
brw_is_color_fast_clear_compatible(struct brw_context *brw,
                                   const struct intel_mipmap_tree *mt,
                                   const union gl_color_union *color);

struct gl_renderbuffer *brw_get_rb_for_slice(struct brw_context *brw,
                                             struct intel_mipmap_tree *mt,
                                             unsigned level, unsigned layer,
                                             bool flat);

#ifdef __cplusplus
}
#endif

#endif /* BRW_META_UTIL_H */

==> mesa_17.0.0~rc2.orig.tar.gz: mesa-17.0.0-rc2/src/mesa/drivers/dri/i965/brw_meta_util.h <==
/*
 * Copyright © 2014 Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

#ifndef BRW_META_UTIL_H
#define BRW_META_UTIL_H

#include <stdbool.h>
#include "main/mtypes.h"
#include "intel_mipmap_tree.h"

#ifdef __cplusplus
extern "C" {
#endif

bool
brw_meta_mirror_clip_and_scissor(const struct gl_context *ctx,
                                 const struct gl_framebuffer *read_fb,
                                 const struct gl_framebuffer *draw_fb,
                                 GLfloat *srcX0, GLfloat *srcY0,
                                 GLfloat *srcX1, GLfloat *srcY1,
                                 GLfloat *dstX0, GLfloat *dstY0,
                                 GLfloat *dstX1, GLfloat *dstY1,
                                 bool *mirror_x, bool *mirror_y);

union gl_color_union
brw_meta_convert_fast_clear_color(const struct brw_context *brw,
                                  const struct intel_mipmap_tree *mt,
                                  const union gl_color_union *color);

bool
brw_meta_set_fast_clear_color(struct brw_context *brw,
                              union gl_color_union *curr_color,
                              const union gl_color_union *new_color);

bool
brw_is_color_fast_clear_compatible(struct brw_context *brw,
                                   const struct intel_mipmap_tree *mt,
                                   const union gl_color_union *color);

struct gl_renderbuffer *brw_get_rb_for_slice(struct brw_context *brw,
                                             struct intel_mipmap_tree *mt,
                                             unsigned level, unsigned layer,
                                             bool flat);

#ifdef __cplusplus
}
#endif

#endif /* BRW_META_UTIL_H */
